package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcYqbg;
import com.ruoyi.tcZz.service.ITcYqbgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 舆情报告Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api("舆情报告")
@RequestMapping("/tcZz/netWorkYq/yqbg")
public class TcYqbgController extends BaseController
{
    @Autowired
    private ITcYqbgService tcYqbgService;

    /**
     * 查询舆情报告列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqbg:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcYqbg tcYqbg)
    {
        startPage();
        List<TcYqbg> list = tcYqbgService.selectTcYqbgList(tcYqbg);
        return getDataTable(list);
    }

    /**
     * 导出舆情报告列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqbg:export')")
    @Log(title = "舆情报告", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqbg tcYqbg)
    {
        List<TcYqbg> list = tcYqbgService.selectTcYqbgList(tcYqbg);
        ExcelUtil<TcYqbg> util = new ExcelUtil<TcYqbg>(TcYqbg.class);
        util.exportExcel(response, list, "舆情报告数据");
    }

    /**
     * 获取舆情报告详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqbg:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqbgService.selectTcYqbgById(id));
    }

    /**
     * 新增舆情报告
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqbg:add')")
    @Log(title = "舆情报告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcYqbg tcYqbg)
    {
        return toAjax(tcYqbgService.insertTcYqbg(tcYqbg));
    }

    /**
     * 修改舆情报告
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqbg:edit')")
    @Log(title = "舆情报告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqbg tcYqbg)
    {
        return toAjax(tcYqbgService.updateTcYqbg(tcYqbg));
    }

    /**
     * 删除舆情报告
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqbg:remove')")
    @Log(title = "舆情报告", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqbgService.deleteTcYqbgByIds(ids));
    }
}
