package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcZbxq;
import com.ruoyi.tcZz.service.ITcZbxqService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 *  转办量、转办详情Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/netWorkYq/zbxq")
public class TcZbxqController extends BaseController
{
    @Autowired
    private ITcZbxqService tcZbxqService;

    /**
     * 查询 转办量、转办详情列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:zbxq:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcZbxq tcZbxq)
    {
        startPage();
        List<TcZbxq> list = tcZbxqService.selectTcZbxqList(tcZbxq);
        return getDataTable(list);
    }

    /**
     * 导出 转办量、转办详情列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:zbxq:export')")
    @Log(title = " 转办量、转办详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZbxq tcZbxq)
    {
        List<TcZbxq> list = tcZbxqService.selectTcZbxqList(tcZbxq);
        ExcelUtil<TcZbxq> util = new ExcelUtil<TcZbxq>(TcZbxq.class);
        util.exportExcel(response, list, " 转办量、转办详情数据");
    }

    /**
     * 获取 转办量、转办详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:zbxq:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZbxqService.selectTcZbxqById(id));
    }

    /**
     * 新增 转办量、转办详情
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:zbxq:add')")
    @Log(title = " 转办量、转办详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcZbxq tcZbxq)
    {
        return toAjax(tcZbxqService.insertTcZbxq(tcZbxq));
    }

    /**
     * 修改 转办量、转办详情
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:zbxq:edit')")
    @Log(title = " 转办量、转办详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcZbxq tcZbxq)
    {
        return toAjax(tcZbxqService.updateTcZbxq(tcZbxq));
    }

    /**
     * 删除 转办量、转办详情
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:zbxq:remove')")
    @Log(title = " 转办量、转办详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZbxqService.deleteTcZbxqByIds(ids));
    }
}
