package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcZdgzxm;
import com.ruoyi.tcZz.service.ITcZdgzxmService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 重点工作项目Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/netManage/zdgzxm")
public class TcZdgzxmController extends BaseController
{
    @Autowired
    private ITcZdgzxmService tcZdgzxmService;

    /**
     * 查询重点工作项目列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdgzxm:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcZdgzxm tcZdgzxm)
    {
        startPage();
        List<TcZdgzxm> list = tcZdgzxmService.selectTcZdgzxmList(tcZdgzxm);
        return getDataTable(list);
    }

    /**
     * 导出重点工作项目列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdgzxm:export')")
    @Log(title = "重点工作项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZdgzxm tcZdgzxm)
    {
        List<TcZdgzxm> list = tcZdgzxmService.selectTcZdgzxmList(tcZdgzxm);
        ExcelUtil<TcZdgzxm> util = new ExcelUtil<TcZdgzxm>(TcZdgzxm.class);
        util.exportExcel(response, list, "重点工作项目数据");
    }

    /**
     * 获取重点工作项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdgzxm:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZdgzxmService.selectTcZdgzxmById(id));
    }

    /**
     * 新增重点工作项目
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdgzxm:add')")
    @Log(title = "重点工作项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcZdgzxm tcZdgzxm)
    {
        return toAjax(tcZdgzxmService.insertTcZdgzxm(tcZdgzxm));
    }

    /**
     * 修改重点工作项目
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdgzxm:edit')")
    @Log(title = "重点工作项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcZdgzxm tcZdgzxm)
    {
        return toAjax(tcZdgzxmService.updateTcZdgzxm(tcZdgzxm));
    }

    /**
     * 删除重点工作项目
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdgzxm:remove')")
    @Log(title = "重点工作项目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZdgzxmService.deleteTcZdgzxmByIds(ids));
    }
}
