package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcZdlyjg;
import com.ruoyi.tcZz.service.ITcZdlyjgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 重点领域监管Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/netManage/zdlyjg")
public class TcZdlyjgController extends BaseController
{
    @Autowired
    private ITcZdlyjgService tcZdlyjgService;

    /**
     * 查询重点领域监管列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdlyjg:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcZdlyjg tcZdlyjg)
    {
        startPage();
        List<TcZdlyjg> list = tcZdlyjgService.selectTcZdlyjgList(tcZdlyjg);
        return getDataTable(list);
    }

    /**
     * 导出重点领域监管列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdlyjg:export')")
    @Log(title = "重点领域监管", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZdlyjg tcZdlyjg)
    {
        List<TcZdlyjg> list = tcZdlyjgService.selectTcZdlyjgList(tcZdlyjg);
        ExcelUtil<TcZdlyjg> util = new ExcelUtil<TcZdlyjg>(TcZdlyjg.class);
        util.exportExcel(response, list, "重点领域监管数据");
    }

    /**
     * 获取重点领域监管详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdlyjg:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZdlyjgService.selectTcZdlyjgById(id));
    }

    /**
     * 新增重点领域监管
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdlyjg:add')")
    @Log(title = "重点领域监管", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcZdlyjg tcZdlyjg)
    {
        return toAjax(tcZdlyjgService.insertTcZdlyjg(tcZdlyjg));
    }

    /**
     * 修改重点领域监管
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdlyjg:edit')")
    @Log(title = "重点领域监管", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcZdlyjg tcZdlyjg)
    {
        return toAjax(tcZdlyjgService.updateTcZdlyjg(tcZdlyjg));
    }

    /**
     * 删除重点领域监管
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdlyjg:remove')")
    @Log(title = "重点领域监管", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZdlyjgService.deleteTcZdlyjgByIds(ids));
    }
}
